SUBROUTINE  StypeEC2CRTM(ATM,Sfc,&
            crtm_stype,&
            clim,surf,iprt)
!
!  CREATION HISTORY:
!         
!       ecmwf_match2_crtm Written by Ron Vogel 2-Aug-2009
!       Code written by
!                 Michiko Masutani  26-Aug-2009
!
! -----------------
! Environment setup
! -----------------
! Module use
USE CRTM_Module
USE Fundamental_Constants
  
IMPLICIT NONE

TYPE(CRTM_Surface_type),INTENT(IN OUT) ::Sfc 
TYPE(CRTM_Atmosphere_type),INTENT(IN)   :: Atm
!
INTEGER:: crtm_stype

!!!!! CODE TO SELECT CRTM Land_Type FROM
!ECMWF Vegetation Parameters:
!
REAL(fp_kind),DIMENSION(*):: surf,clim
REAL(fp_kind) :: cover_low_veg 
             ! Fractional cover low vegetation (real 0. - 1.)
REAL(fp_kind) :: cover_high_veg 
             ! Fractional cover high vegetation (real 0. - 1.)
INTEGER :: type_low_veg ! Low vegetation type (integer)
INTEGER :: type_high_veg ! High vegetation type (integer)
!
REAL(fp_kind):: snow_depth_we
! Folowing variable are not used but keep for later use
REAL(fp_kind):: snow_albedo, snow_density,snow_evapolation, snowmelt,&
           snow_fall
REAL(fp_kind):: u10m,v10m,cldt,cldl,cldm,cldh,ice_cover,sktp

REAL(fp_kind):: LS_mask! land sea mask  1: land, 0: ocean
REAL(fp_kind)::terr,gg
!
!ECMWF to CRTM match-up
!
!!! CRTM TYPE !!                !! EMCWF TYPE !!!
INTEGER::ecmwf_match2_crtm(20)
INTEGER::iprt,iprt0,iprt_mm
data iprt_mm/5/
DATA ecmwf_match2_crtm/   &
 5 , &                ! CROPS
 10 , &               ! SHORT GRASS
 12 , &                ! EVERGREEN NEEDLELEAF
 12 , &                ! DECIDUOUS NEEDLELEAF
 11 , &           !DECIDUOUS BROADLEAF
 11 , &           ! EVERGREEN BROADLEAF
 20, &            ! TALL GRASS
 0 , &               ! DESERT
 13 , &                     ! TUNDRA
 5 , &                ! IRRIGATED CROPS
 22 , &                 ! SEMIDESERT
 24 , &               ! ICE CAPS AND GLACIERS
 20 , &            ! BOGS AND MARSHES
 0 , &               ! INLAND WATER
 0 , &               ! OCEAN
 10 , &                      ! EVERGREEN SHRUBS
 10 , &                      ! DECIDUOUS SHRUBS
 23, &       ! MIXED FOREST / WOODLAND
 23, &       ! INTERRUPTED FOREST
 0 /                ! WATER AND LAND MIXTURES
!
!
!
! ----------------------------------------------------------------------------------------
! The 24 surface types are:
!    1.     water             2.  old snow                  3.   fresh snow
!    4.  compacted soil       5.  tilled soil               6.   sand
!    7.     rock              8.  irrigated low vegetation  9.   meadow grass
!   10.    scrub             11.  broadleaf forest         12.   pine forest
!   13.    tundra            14.  grass soil               15.   broadleaf pine forest
!   16.    grass scrub       17.  oil grass                18.   urban concrete
!   19.    pine brush        20.  broadleaf brush          21.   wet soil
!   22.    scrub soil        23.  broadleaf 70-pine 30     24.   new ice
! ----------------------------------------------------------------------------------------
!
! Logic to select CRTM Land Type from ECMWF Vegetation Parameters
!
! ecclim
!      ecclm(1)='iv=27 ! low  vegetation cover'
!      ecclm(2)='iv=28 ! high vegetation cover'
!      ecclm(3)='iv=29 ! low  vegetation type'
!      ecclm(4)='iv=30 ! high vegetation type'
!
!
!  Used values in ecsfc 
!
!  1   kpds=031    Sea-ice cover [(0-1)]
!  33  kpds=172    Land/sea mask [(0, 1)]
!  56  kpds=235    Skin temperature [K] 
!  snow:
!  2   kpds=032    Snow albedo [(0-1)]
!  3   kpds=033    Snow density [kg m**-3]
!  5   kpds=044    Snow evaporation [m of water
!  6   kpds=045    Snowmelt [m of water]
!  16   kpds=141    Snow depth [m of water equiv
!  19   kpds=144    Snowfall (convective + strat
      iprt0=iprt
!      iprt=iprt_mm
      gg=STANDARD_GRAVITY
      crtm_stype=1   ! water
      if (iprt.ge.5) print*,'StypeEC2CRTM called',iprt
      if (iprt.ge.5) then
        print*,'ecmwf_match2_crtm', ecmwf_match2_crtm
        print*,'gg=',gg
      endif
      cover_low_veg=clim(1)
      cover_high_veg=clim(2)
      type_low_veg=clim(3)
      type_high_veg=clim(4)
      terr=surf(13)/gg
      u10m=surf(28)
      v10m=surf(29)
      cldt=surf(27)
      cldl=surf(42)
      cldm=surf(43)
      cldh=surf(44)
      ice_cover=surf(1)   ! msq 090729
      LS_mask=surf(33) ! msq 090729
      sktp=surf(56)
      snow_albedo=surf(2)
      snow_density=surf(3)
      snow_evapolation=surf(5)
      snow_depth_we=surf(16)
      snow_fall=surf(19)

if (iprt.ge.4) then
    print*,'cover_low_veg,cover_high_veg,type_low_veg,type_high_veg,terr',&
       ',u10m,v10m,cldt,cldl,cldm,cldh,ice_cover, LS_mask, sktp, snow_depth_we'
    print*,cover_low_veg,cover_high_veg,type_low_veg,type_high_veg,terr,&
       u10m,v10m,cldt,cldl,cldm,cldh,ice_cover, LS_mask, sktp, snow_depth_we
endif

if (LS_mask > 0.5) then
   IF (( cover_low_veg .LT. 0.1 ) .AND. ( cover_high_veg .LT. 0.1 )) THEN
        crtm_stype = 4    ! compacted soil
   ELSE
        IF ( cover_high_veg .GE. cover_low_veg ) THEN
              crtm_stype = ecmwf_match2_crtm(type_high_veg)
        ELSE 
              crtm_stype = ecmwf_match2_crtm(type_low_veg)
        END IF
   END IF


!
!Snow water equivalent (snow melt, SWE from ECMWF) needs to be changed to snow
!depth. Multiply by conversion factor 5 for old snow,
! and 10 for fresh snow.
! For IR sensor fresh snow is not used.  All snow us assumer to be CRUST_SNOW
!
     Sfc%snow_depth =1000.00* snow_depth_we* 5 !  conversion factor for old snow 5
!
   if ( Sfc%snow_depth > 0.1) then  ! based on Weizhong Zheng's GSI code
      crtm_stype=2
   else
      crtm_stype=3
   endif
!
!  For MW sensor this part have to be changed but do not know how, yet.
!
!     f10     - interpolated 10m factor
!     computed using compute_fact10 in gsi
!     need surface roughness
!     Sfc%wind_speed            = f10*sqrt(u10m*u10m+v10m*v10m)
!     Sfc%water_temperature     = sktp
!     Sfc%land_temperature      = sktp
!     Sfc%ice_temperature       = sktp
!     Sfc%snow_temperature      = sktp
!     Sfc%soil_temperature      = sktp



      Sfc%Land_Coverage = 0.0
      Sfc%Water_Coverage = 0.0
      Sfc%Snow_Coverage = 0.0
      Sfc%Ice_Coverage = 0.0
      



     IF( crtm_stype == 1 ) THEN
        if (crtm_stype==1) then
             print*,' water over the land. check the logic',crtm_stype,LS_Mask
             print*,' set as water '
        endif
        Sfc%Water_Coverage = 1.0
        Sfc%Water_Type = SEA_WATER
        Sfc%Water_Temperature = sktp
        Sfc%Wind_Speed = sqrt(u10m*u10m+v10m*v10m)
        if (ABS(Sfc%Wind_Speed).lt.0.1) then
            Sfc%Wind_Direction = 0.0
        else
        Sfc%Wind_Direction = &
                  ACOS(u10m/Sfc%Wind_Speed) * 180.0/3.14159
        endif
        Sfc%Salinity = 33.0
      ELSE IF(crtm_stype == 2 ) then
        Sfc%Snow_Coverage = 1.0
        Sfc%Snow_Temperature = sktp
        Sfc%Snow_Depth = 0.1
        Sfc%Snow_Density = 0.1
        Sfc%Snow_Grain_Size = 0.1
        Sfc%Snow_Type = CRUST_SNOW
      ELSE IF(crtm_stype == 3 ) then  
        Sfc%Snow_Coverage = 1.0
        Sfc%Snow_Temperature = sktp
        Sfc%Snow_Depth = 0.1
        Sfc%Snow_Density = 0.1
        Sfc%Snow_Grain_Size = 0.1
        Sfc%Snow_Type = NEW_SNOW
      ELSE IF(crtm_stype == 24 ) THEN
        Sfc%Ice_Coverage = 1.0
        Sfc%Ice_Type = FRESH_ICE
        Sfc%Ice_Temperature = sktp 
        Sfc%Ice_Thickness = 0.1
        Sfc%Ice_Density = 0.9
        Sfc%Ice_Roughness = 0.1
      ELSE
        Sfc%Land_Coverage = 1.0
        Sfc%Land_Type = crtm_stype - 3   !!!!????
        Sfc%Land_Temperature = sktp
        Sfc%Soil_Moisture_Content = 0.1
        Sfc%Canopy_Water_Content = 0.05
        Sfc%Vegetation_Fraction = 0.5
        Sfc%Soil_Temperature = sktp
      ENDIF


else
!  Over Ocean 
   Sfc%Ice_Coverage = ice_cover
   Sfc%Water_Coverage = 1.0-ice_cover
   Sfc%Ice_Temperature = sktp 
   Sfc%Water_Temperature = sktp
   Sfc%Wind_Speed = sqrt(u10m*u10m+v10m*v10m)
        if (ABS(Sfc%Wind_Speed).lt.0.1) then
            Sfc%Wind_Direction = 0.0
        else
            Sfc%Wind_Direction = &
                  ACOS(u10m/Sfc%Wind_Speed) * 180.0/3.14159
        endif
   Sfc%Salinity = 33.0
   if (ice_cover .GE. 0.1) then
   crtm_stype=24
   else
   crtm_stype=1
   endif
endif

iprt=iprt0
return
end subroutine StypeEC2CRTM
