SUBROUTINE  StypeGFS2CRTM(ATM,Sfc,&
            crtm_stype,&
            clim,surf,sat_type,iprt)
!
!  CREATION HISTORY:
!         
!      gdas_vegtype   Written by Ron Vogel  Dec 2009
!      Code written by
!                 Michiko Masutani  Jan 2010 
!
! -----------------
! Environment setup
! -----------------
! Module use
USE CRTM_Module
USE Fundamental_Constants
  
IMPLICIT NONE

TYPE(CRTM_Surface_type),INTENT(IN OUT) ::Sfc 
TYPE(CRTM_Atmosphere_type),INTENT(IN)   :: Atm
!
INTEGER::sat_type
INTEGER:: crtm_stype
!
!  sat_type
!   # sat type 1: Micro 2; IR Hirs 3: GOES  4:AIRS IASI
!

!!!!! CODE TO SELECT CRTM Land_Type FROM
!
!The GFS/GDAS vegetation types are (numbered 1 to 13):
!
!  1  ...  broadleave-evergreen trees (tropical forest)
!  2  ...  broadleave-deciduous trees
!  3  ...  broadleave and needle leave trees (mixed forest)
!  4  ...  needleleave-evergreen trees
!  5  ...  needleleave-deciduous trees (larch)
!  6  ...  broadleave trees with groundcover (savanna)
!  7  ...  groundcover only (perenial)
!  8  ...  broadleave shrubs with perenial groundcover
!  9  ...  broadleave shrubs with bare soil
! 10  ...  dwarf trees and shrubs with ground cover (trunda)
! 11  ...  bare soil
! 12  ...  cultivations (use parameters from type 7)
! 13  ...  glacial
!
! ----------------------------------------------------------------------------------------
! The 24 surface crtm types are:
!    1.     water             2.  old snow                  3.   fresh snow
!    4.  compacted soil       5.  tilled soil               6.   sand
!    7.     rock              8.  irrigated low vegetation  9.   meadow grass
!   10.    scrub             11.  broadleaf forest         12.   pine forest
!   13.    tundra            14.  grass soil               15.   broadleaf pine forest
!   16.    grass scrub       17.  oil grass                18.   urban concrete
!   19.    pine brush        20.  broadleaf brush          21.   wet soil
!   22.    scrub soil        23.  broadleaf 70-pine 30     24.   new ice
! ----------------------------------------------------------------------------------------
!
!
!Variable declarations
!
! match GDAS veg types (integers 1-13) to
! CRTM surface type crtm_stype 
INTEGER, DIMENSION(13), PARAMETER :: gfs_match2_crtm= &
      (/ 8, 8, 12, 9, 9, 17, 7, 7, 19, 10, 1, 2, 1 /)
!
!
REAL(fp_kind),DIMENSION(*):: surf,clim
REAL(fp_kind) :: cover_low_veg 
             ! Fractional cover low vegetation (real 0. - 1.)
REAL(fp_kind) :: cover_high_veg 
             ! Fractional cover high vegetation (real 0. - 1.)
INTEGER :: type_low_veg ! Low vegetation type (integer)
INTEGER :: type_high_veg ! High vegetation type (integer)
!
REAL(fp_kind):: snow_depth_we
! Folowing variable are not used but keep for later use
REAL(fp_kind):: snow_albedo, snow_density,snow_evapolation, snowmelt,&
           snow_fall
REAL(fp_kind):: u10m,v10m,cldt,cldl,cldm,cldh,ice_cover,sktp

REAL(fp_kind):: LS_mask! land sea mask  1: land, 0: ocean
REAL(fp_kind)::terr,gg
!
INTEGER::iprt,iprt0,iprt_mm
data iprt_mm/5/
!
!
! Logic to select CRTM Land Type from ECMWF Vegetation Parameters
!
! gfsclim
!      gfsclm(1)='iv=27 ! low  vegetation cover'
!      gfsclm(2)='iv=28 ! high vegetation cover'
!      gfsclm(3)='iv=29 ! low  vegetation type'
!      gfsclm(4)='iv=30 ! high vegetation type'
!
!
!  Used values in ecsfc 
!
!  1   kpds=031    Sea-ice cover [(0-1)]
!  33  kpds=172    Land/sea mask [(0, 1)]
!  56  kpds=235    Skin temperature [K] 
!  snow:
!  2   kpds=032    Snow albedo [(0-1)]
!  3   kpds=033    Snow density [kg m**-3]
!  5   kpds=044    Snow evaporation [m of water
!  6   kpds=045    Snowmelt [m of water]
!  16   kpds=141    Snow depth [m of water equiv
!  19   kpds=144    Snowfall (convective + strat
      iprt0=iprt
!      iprt=iprt_mm
      gg=STANDARD_GRAVITY
      crtm_stype=1   ! water
      if (iprt.ge.5) print*,'StypeEC2CRTM called',iprt
      if (iprt.ge.5) then
        print*,'gfs_match2_crtm', gfs_match2_crtm
        print*,'gg=',gg
      endif
      cover_low_veg=clim(1)
      cover_high_veg=clim(2)
      type_low_veg=clim(3)
      type_high_veg=clim(4)
      terr=surf(13)/gg
      u10m=surf(28)
      v10m=surf(29)
      cldt=surf(27)
      cldl=surf(42)
      cldm=surf(43)
      cldh=surf(44)
      ice_cover=surf(1)   ! msq 090729
      LS_mask=surf(33) ! msq 090729
      sktp=surf(56)
      snow_albedo=surf(2)
      snow_density=surf(3)
      snow_evapolation=surf(5)
      snow_depth_we=surf(16)
      snow_fall=surf(19)

if (iprt.ge.4) then
    print*,'cover_low_veg,cover_high_veg,type_low_veg,type_high_veg,terr',&
       ',u10m,v10m,cldt,cldl,cldm,cldh,ice_cover, LS_mask, sktp, snow_depth_we'
    print*,cover_low_veg,cover_high_veg,type_low_veg,type_high_veg,terr,&
       u10m,v10m,cldt,cldl,cldm,cldh,ice_cover, LS_mask, sktp, snow_depth_we
endif


      Sfc%Land_Coverage = 0.0
      Sfc%Water_Coverage = 0.0
      Sfc%Snow_Coverage = 0.0
      Sfc%Ice_Coverage = 0.0
      
if (LS_mask > 0.5) then
   IF (( cover_low_veg .LT. 0.1 ) .AND. ( cover_high_veg .LT. 0.1 )) THEN
        crtm_stype = 4    ! compacted soil
   ELSE
!        gfs  veg type mapped to CRTM surface type
        IF ( cover_high_veg .GE. cover_low_veg ) THEN
              crtm_stype = gfs_match2_crtm(type_high_veg)
        ELSE
              crtm_stype = gfs_match2_crtm(type_low_veg)
        END IF
    END IF
!
!
!
! ////////// Snow over Land ///////////////////
!
!Note that snow surface is treated differently. As long as
!snow has a depth of 0.1 mm then one of CRTM's two snow types
!is used (fresh snow orold snow), regardless of the vegetation
!type. Old snow (code below) is used by Ron Vogel.
!
!   Sfc%Snow_Type = 13  will be used 
! CRTM 'CRUST_SNOW (13)' maps to 'old snow' emissivity
!
!Snow water equivalent (snow melt, SWE from ECMWF) needs to be changed to snow
!depth. Multiply by conversion factor 5 for old snow,
! and 10 for fresh snow.
! For IR sensor fresh snow is not used.  All snow us assumer to be CRUST_SNOW
!
     Sfc%snow_depth =1000.00* snow_depth_we* 5 !  conversion factor for old snow 5
!
   if ( Sfc%snow_depth > 0.1) then  ! based on Weizhong Zheng's GSI code
      crtm_stype=2
   else
      crtm_stype=3
   endif
!
!  For MW sensor this part have to be changed but do not know how, yet.
!
!     f10     - interpolated 10m factor
!     computed using compute_fact10 in gsi
!     need surface roughness
!     Sfc%wind_speed            = f10*sqrt(u10m*u10m+v10m*v10m)
!     Sfc%water_temperature     = sktp
!     Sfc%land_temperature      = sktp
!     Sfc%ice_temperature       = sktp
!     Sfc%snow_temperature      = sktp
!     Sfc%soil_temperature      = sktp





     IF( crtm_stype == 1 ) THEN
        if ( iprt.ge.4 ) then
             print*,' water over the land. check the logic',crtm_stype,LS_Mask
             print*,' set as water '
        endif
        Sfc%Water_Coverage = 1.0
        Sfc%Water_Type = 2     !Fresh Water
        Sfc%Water_Temperature = sktp
        Sfc%Wind_Speed = sqrt(u10m*u10m+v10m*v10m)
        if (ABS(Sfc%Wind_Speed).lt.0.1) then
            Sfc%Wind_Direction = 0.0
        else
        Sfc%Wind_Direction = &
                  ACOS(u10m/Sfc%Wind_Speed) * 180.0/3.14159
        endif
        Sfc%Salinity = 33.0
      ELSE IF(crtm_stype == 2 ) then
        Sfc%Snow_Coverage = 1.0
        Sfc%Snow_Temperature = sktp
        Sfc%Snow_Depth = 0.1
        Sfc%Snow_Density = 0.1
        Sfc%Snow_Grain_Size = 0.1
        Sfc%Snow_Type = CRUST_SNOW
      ELSE IF(crtm_stype == 3 ) then  
        Sfc%Snow_Coverage = 1.0
        Sfc%Snow_Temperature = sktp
        Sfc%Snow_Depth = 0.1
        Sfc%Snow_Density = 0.1
        Sfc%Snow_Grain_Size = 0.1
        Sfc%Snow_Type = NEW_SNOW
      ELSE IF(crtm_stype == 24 ) THEN
        Sfc%Ice_Coverage = 1.0
        Sfc%Ice_Type = FRESH_ICE
        Sfc%Ice_Temperature = sktp 
        Sfc%Ice_Thickness = 0.1
        Sfc%Ice_Density = 0.9
        Sfc%Ice_Roughness = 0.1
      ELSE
        Sfc%Land_Coverage = 1.0
        Sfc%Land_Type = crtm_stype - 3   !!!!????  OK!!
        Sfc%Land_Temperature = sktp
        Sfc%Soil_Moisture_Content = 0.1
        Sfc%Canopy_Water_Content = 0.05
        Sfc%Vegetation_Fraction = 0.5
        Sfc%Soil_Temperature = sktp
      ENDIF


else
!  Over Ocean 
   Sfc%Ice_Coverage = ice_cover
   Sfc%Water_Coverage = 1.0-ice_cover
   Sfc%Ice_Temperature = sktp 
   Sfc%Water_Temperature = sktp
   Sfc%Wind_Speed = sqrt(u10m*u10m+v10m*v10m)
        if (ABS(Sfc%Wind_Speed).lt.0.1) then
            Sfc%Wind_Direction = 0.0
        else
            Sfc%Wind_Direction = &
                  ACOS(u10m/Sfc%Wind_Speed) * 180.0/3.14159
        endif
   Sfc%Salinity = 33.0
   if (ice_cover > 0.1) then
      crtm_stype=24
   else
      crtm_stype=1
   endif
endif ! LS_mask>0.5 

iprt=iprt0
return
end subroutine StypeGFS2CRTM
